NoneBot.log 模块 | NoneBot
Description: 跨平台 Python 异步 QQ 机器人框架

# # NoneBot.log 模块

## # 日志

NoneBot 使用 loguru
(opens new window) 来记录日志信息。

自定义 logger 请参考 loguru
(opens new window) 文档。

## # `logger`

- 说明

  NoneBot 日志记录器对象。

- 默认信息

  - 格式: `[%(asctime)s %(name)s] %(levelname)s: %(message)s`

  - 等级: `DEBUG` / `INFO` ，根据 config 配置改变

  - 输出: 输出至 stdout

- 用法

    from nonebot.log import logger

1

## # class `LoguruHandler`

基类：`logging.Handler`

### # `emit(record)`

Do whatever it takes to actually log the specified logging record.

This version is intended to be implemented by subclasses and so raises a NotImplementedError.

Contents

- 日志
- logger
- class LoguruHandler
  - emit(record)